@@ -11,32 +11,32 @@
 #include "putseq.h"
 #include <simage_private.h>
 
-static int 
+static int
 SimpegWrite_encode(const char * output_filename,
                    const char * parameter_filename,
-                   SimpegWrite_error_cb error_cb, 
+                   SimpegWrite_error_cb error_cb,
                    SimpegWrite_warning_cb warning_cb,
                    SimpegWrite_progress_cb progress_cb,
                    void * cbuserdata);
 
 
-static void * 
+static void *
 SimpegWrite_begin_encode(const char * output_filename,
                          const char * parameter_filename,
-                         SimpegWrite_error_cb error_cb, 
+                         SimpegWrite_error_cb error_cb,
                          SimpegWrite_warning_cb warning_cb,
                          SimpegWrite_progress_cb progress_cb,
                          void * cbuserdata,
-                         int w, int h, int numframes, int mpeg1, int level); 
+                         int w, int h, int numframes, int mpeg1, int level, float bitrate);
 
-static int 
+static int
 SimpegWrite_encode_bitmap(void * handle, const unsigned char * rgb_buffer);
 
-static int 
+static int
 SimpegWrite_end_encode(void * handle);
 
 /* simage movie interface */
-int 
+int
 mpeg2enc_movie_create(const char * filename, s_movie * movie, s_params * params)
 {
   void * handle;
@@ -46,12 +46,15 @@ mpeg2enc_movie_create(const char * filename, s_movie * movie, s_params * params)
   int w, h, numframes;
   int mpeg1;
   int level;
+  int bitrate;
   const char *mime_type;
 
+
   w = h = 0;
   numframes = 0;
   mpeg1 = 0;
   level=0;
+  bitrate = -1;
 
   paramfile = NULL;
   cb0 = NULL;
@@ -59,36 +62,36 @@ mpeg2enc_movie_create(const char * filename, s_movie * movie, s_params * params)
   cb2 = NULL;
   mime_type = NULL;
 
-  s_params_get(params, 
+  s_params_get(params,
                "mime-type", S_STRING_PARAM_TYPE, &mime_type, NULL);
 
   if (!mime_type || (strcmp(mime_type, "video/mpeg") != 0)) {
     return 0;
   }
 
-  /* Note 20020321 thammer: 
+  /* Note 20020321 thammer:
      The video/mpeg mime type is defined in RFC 2046 "MIME Part Two: Media Types".
      http://www.nacs.uci.edu/indiv/ehood/MIME/2046/rfc2046.html
   */
 
-  s_params_get(params, 
+  s_params_get(params,
                "parameter file", S_STRING_PARAM_TYPE, &paramfile, NULL);
 
-  s_params_get(params, 
+  s_params_get(params,
                "error callback", S_FUNCTION_PARAM_TYPE, &cb0, NULL);
 
-  s_params_get(params, 
+  s_params_get(params,
                "warning callback", S_FUNCTION_PARAM_TYPE, &cb1, NULL);
 
-  s_params_get(params, 
+  s_params_get(params,
                "progress callback", S_FUNCTION_PARAM_TYPE, &cb2, NULL);
 
   s_params_get(params,
                "callback userdata", S_POINTER_PARAM_TYPE, &cbdata, NULL);
-  
+
   s_params_get(params,
                "width", S_INTEGER_PARAM_TYPE, &w, NULL);
-  
+
   s_params_get(params,
               "height", S_INTEGER_PARAM_TYPE, &h, NULL);
 
@@ -101,10 +104,14 @@ mpeg2enc_movie_create(const char * filename, s_movie * movie, s_params * params)
   s_params_get(params,
                "level", S_INTEGER_PARAM_TYPE, &level, NULL);
 
-/* 
+
+  s_params_get(params,
+  			   "bitrate", S_INTEGER_PARAM_TYPE, &bitrate, NULL);
+
+/*
   Level ID
 
-  Specifies coded parameter constraints, such as bitrate, sample rate, and 
+  Specifies coded parameter constraints, such as bitrate, sample rate, and
   maximum allowed motion vector range.
 
   Code  Meaning         Typical use
@@ -114,21 +121,21 @@ mpeg2enc_movie_create(const char * filename, s_movie * movie, s_params * params)
   8     Main Level      CCIR 601 rates: e.g. 720 x 480 x 30 Hz
   10    Low Level       SIF video rate: e.g. 352 x 240 x 30 Hz
 */
-  
-  handle = SimpegWrite_begin_encode(filename, 
-                                    paramfile, 
-                                    (SimpegWrite_error_cb) cb0, 
-                                    (SimpegWrite_warning_cb) cb1, 
+
+  handle = SimpegWrite_begin_encode(filename,
+                                    paramfile,
+                                    (SimpegWrite_error_cb) cb0,
+                                    (SimpegWrite_warning_cb) cb1,
                                     (SimpegWrite_progress_cb) cb2,
                                     cbdata,
-                                    w, h, numframes, mpeg1, level);
+                                    w, h, numframes, mpeg1, level, (float) bitrate);
   if (handle == NULL) return 0;
-  
+
   s_params_set(s_movie_params(movie), "mpeg2enc handle", S_POINTER_PARAM_TYPE, handle, 0);
   return 1;
 }
 
-int 
+int
 mpeg2enc_movie_put(s_movie * movie, s_image * image, s_params * params)
 {
   void * handle;
@@ -139,7 +146,7 @@ mpeg2enc_movie_put(s_movie * movie, s_image * image, s_params * params)
   return 0;
 }
 
-void 
+void
 mpeg2enc_movie_close(s_movie * movie)
 {
   void * handle;
@@ -152,8 +159,8 @@ mpeg2enc_movie_close(s_movie * movie)
 /* private prototypes */
 static void init(simpeg_encode_context * context);
 static void init_context_data(simpeg_encode_context * context);
-static void readparmfile(simpeg_encode_context * context, const char *fname, 
-                         int w, int h, int numframes, int mpeg1, int level);
+static void readparmfile(simpeg_encode_context * context, const char *fname,
+                         int w, int h, int numframes, int mpeg1, int level, float bitrate);
 static void readquantmat(simpeg_encode_context * context);
 static void cleanup(simpeg_encode_context * context);
 
@@ -161,16 +168,16 @@ static void cleanup(simpeg_encode_context * context);
 
 /* fixme: statfile -> ignore */
 
-static int 
+static int
 SimpegWrite_encode(const char *output_filename,
-                   const char *parameter_filename, 
-                   SimpegWrite_error_cb error_cb, 
+                   const char *parameter_filename,
+                   SimpegWrite_error_cb error_cb,
                    SimpegWrite_warning_cb warning_cb,
                    SimpegWrite_progress_cb progress_cb,
                    void * cbuserdata)
 {
   simpeg_encode_context * context;
-  
+
   context = (simpeg_encode_context*) malloc(sizeof(simpeg_encode_context));
 
   if (setjmp(context->jmpbuf)) {
@@ -196,7 +203,7 @@ SimpegWrite_encode(const char *output_filename,
 
 
   /* read parameter file */
-  readparmfile(context, parameter_filename, 0, 0, 0, 0, 0);
+  readparmfile(context, parameter_filename, 0, 0, 0, 0, 0, 0.0f);
 
   /* read quantization matrices */
   readquantmat(context);
@@ -217,21 +224,21 @@ SimpegWrite_encode(const char *output_filename,
   free(context);
 
   return 1; /* ok */
-}; 
+};
 
 
-static void * 
+static void *
 SimpegWrite_begin_encode(const char *output_filename,
                          const char *parameter_filename,
-                         SimpegWrite_error_cb error_cb, 
+                         SimpegWrite_error_cb error_cb,
                          SimpegWrite_warning_cb warning_cb,
                          SimpegWrite_progress_cb progress_cb,
                          void * cbuserdata,
-                         int w, int h, int numframes, int mpeg1, int level)
+                         int w, int h, int numframes, int mpeg1, int level, float bitrate)
 {
   int i;
   simpeg_encode_context * context;
-  
+
   context = (simpeg_encode_context*) malloc(sizeof(simpeg_encode_context));
   init_context_data(context);
 
@@ -241,7 +248,7 @@ SimpegWrite_begin_encode(const char *output_filename,
     free(context);
     return NULL;
   }
-  
+
   context->SimpegWrite_error_cb_user = error_cb;
   context->SimpegWrite_warning_cb_user = warning_cb;
   context->SimpegWrite_progress_cb_user = progress_cb;
@@ -258,7 +265,7 @@ SimpegWrite_begin_encode(const char *output_filename,
   context->bufbuf = NULL;
 
   /* read parameter file */
-  readparmfile(context, parameter_filename, w, h, numframes, mpeg1, level);
+  readparmfile(context, parameter_filename, w, h, numframes, mpeg1, level, bitrate);
 
   /* read quantization matrices */
   readquantmat(context);
@@ -274,15 +281,15 @@ SimpegWrite_begin_encode(const char *output_filename,
 
   SimpegWrite_putseq_begin(context);
 
-  context->bufbuf = (unsigned char **) 
+  context->bufbuf = (unsigned char **)
     malloc(sizeof(unsigned char *) * context->M);
   for (i=0; i<context->M; i++)
     context->bufbuf[i] = NULL;
 
   return (void*) context;
-}; 
+};
 
-static int 
+static int
 SimpegWrite_encode_bitmap(void * handle, const unsigned char *rgb_buffer)
 {
   int i;
@@ -299,7 +306,7 @@ SimpegWrite_encode_bitmap(void * handle, const unsigned char *rgb_buffer)
     /* encode the buffered ones */
     for (i = 0; i < context->M; i++) {
       if (context->bufbuf[i] != NULL)
-        SimpegWrite_putseq_encode_bitmap((simpeg_encode_context*) handle, 
+        SimpegWrite_putseq_encode_bitmap((simpeg_encode_context*) handle,
                                          context->bufbuf[i]);
     }
     /* clean buffer */
@@ -311,18 +318,18 @@ SimpegWrite_encode_bitmap(void * handle, const unsigned char *rgb_buffer)
     }
   }
   else {
-    context->bufbuf[(context->SimpegWrite_current_input_frame)%context->M] = 
+    context->bufbuf[(context->SimpegWrite_current_input_frame)%context->M] =
       (unsigned char *) malloc(context->vertical_size * context->horizontal_size * 3);
     memcpy(context->bufbuf[(context->SimpegWrite_current_input_frame)%context->M],
            rgb_buffer, context->vertical_size * context->horizontal_size * 3);
   }
-  
+
   context->SimpegWrite_current_input_frame++;
-  
+
   return 1; /* ok */
 };
 
-static int 
+static int
 SimpegWrite_end_encode(void * handle)
 {
   int i;
@@ -338,11 +345,11 @@ SimpegWrite_end_encode(void * handle)
   /* before we're done - encode any buffered frames */
   for (i=0; i<context->M; i++) {
     if (context->bufbuf[i] != NULL) {
-      SimpegWrite_putseq_encode_bitmap((simpeg_encode_context*) handle, 
+      SimpegWrite_putseq_encode_bitmap((simpeg_encode_context*) handle,
                                        context->bufbuf[i]);
     }
   }
-  
+
   /* finish sequence */
 
   SimpegWrite_putseq_end(context);
@@ -352,7 +359,7 @@ SimpegWrite_end_encode(void * handle)
   return 1;
 };
 
-static void 
+static void
 cleanup(simpeg_encode_context * context)
 {
   int i;
@@ -382,7 +389,7 @@ cleanup(simpeg_encode_context * context)
     fclose(context->statfile);
     context->statfile = NULL;
   }
-  
+
   if (context->mbinfo) free(context->mbinfo);
   if (context->motion_data) free(context->motion_data);
   if (context->blocks) free(context->blocks);
@@ -418,7 +425,7 @@ void SimpegWrite_error(simpeg_encode_context * context, const char *text, ...)
     va_start(p, text);
     vsprintf(buf, text, p);
     va_end(p);
-    
+
     context->SimpegWrite_error_cb_user(context->cbuserdata, buf);
   }
   longjmp(context->jmpbuf, 1);
@@ -432,7 +439,7 @@ void SimpegWrite_warning(simpeg_encode_context * context,const char *text, ...)
     va_start(p, text);
     vsprintf(buf, text, p);
     va_end(p);
-    
+
     context->SimpegWrite_warning_cb_user(context->cbuserdata, buf);
   }
 };
@@ -446,7 +453,7 @@ int SimpegWrite_progress(simpeg_encode_context * context, float sub, int current
 };
 
 
-static void 
+static void
 init(simpeg_encode_context * context)
 {
   int i, size;
@@ -469,7 +476,7 @@ init(simpeg_encode_context * context)
   context->height2 = context->fieldpic ? context->height>>1 : context->height;
   context->width2 = context->fieldpic ? context->width<<1 : context->width;
   context->chrom_width2 = context->fieldpic ? context->chrom_width<<1 : context->chrom_width;
-  
+
   context->block_count = block_count_tab[context->chroma_format-1];
 
   /* clip table */
@@ -482,7 +489,7 @@ init(simpeg_encode_context * context)
 
   for (i=0; i < 3; i++) {
     size = (i==0) ? context->width*context->height : context->chrom_width*context->chrom_height;
-    
+
     if (!(context->newrefframe[i] = (unsigned char *)malloc(size)))
       simpeg_encode_error(context, "malloc failed\n");
     if (!(context->oldrefframe[i] = (unsigned char *)malloc(size)))
@@ -506,7 +513,7 @@ init(simpeg_encode_context * context)
 
   context->blocks =
     (short (*)[64])malloc(context->mb_width*context->mb_height2*context->block_count*sizeof(short [64]));
-  
+
   if (!context->blocks)
     simpeg_encode_error(context, "malloc failed\n");
 
@@ -514,7 +521,7 @@ init(simpeg_encode_context * context)
   if (context->statname[0]=='-')
     context->statfile = stdout;
   else if (context->statname[0]=='%') /* 20010516 thammer we don't want to output to a statfile */
-    context->statfile = NULL; 
+    context->statfile = NULL;
   else if (!(context->statfile = fopen(context->statname,"w")))
   {
     sprintf(context->errortext,"Couldn't create statistics output file %s",context->statname);
@@ -527,9 +534,9 @@ void simpeg_encode_error(simpeg_encode_context * context, char *text)
   SimpegWrite_error(context, text);
 }
 
-static void 
+static void
 readparmfile(simpeg_encode_context * context,
-             const char *fname, int width, int height, int numframes, int mpeg1, int level)
+             const char *fname, int width, int height, int numframes, int mpeg1, int level, float bitrate)
 {
   int i;
   int h, m, s, f;
@@ -537,13 +544,13 @@ readparmfile(simpeg_encode_context * context,
   char line[256];
   static double ratetab[8]=
     {24000.0/1001.0,24.0,25.0,30000.0/1001.0,30.0,50.0,60000.0/1001.0,60.0};
-  
+
   if (fname) {
     if (!(fd = fopen(fname,"r"))) {
       sprintf(context->errortext,"Couldn't open parameter file %s",fname);
         simpeg_encode_error(context, context->errortext);
     }
-    
+
     fgets(context->id_string,254,fd);
     fgets(line,254,fd); sscanf(line,"%s",context->tplorg);
     fgets(line,254,fd); sscanf(line,"%s",context->tplref);
@@ -568,8 +575,8 @@ readparmfile(simpeg_encode_context * context,
     fgets(line,254,fd); sscanf(line,"%d",&context->aspectratio);
     fgets(line,254,fd); sscanf(line,"%d",&context->frame_rate_code);
     fgets(line,254,fd); sscanf(line,"%lf",&context->bit_rate);
-    fgets(line,254,fd); sscanf(line,"%d",&context->vbv_buffer_size);   
-    fgets(line,254,fd); sscanf(line,"%d",&context->low_delay);     
+    fgets(line,254,fd); sscanf(line,"%d",&context->vbv_buffer_size);
+    fgets(line,254,fd); sscanf(line,"%d",&context->low_delay);
     fgets(line,254,fd); sscanf(line,"%d",&context->constrparms);
     fgets(line,254,fd); sscanf(line,"%d",&context->profile);
     fgets(line,254,fd); sscanf(line,"%d",&context->level);
@@ -582,7 +589,7 @@ readparmfile(simpeg_encode_context * context,
     fgets(line,254,fd); sscanf(line,"%d",&context->matrix_coefficients);
     fgets(line,254,fd); sscanf(line,"%d",&context->display_horizontal_size);
     fgets(line,254,fd); sscanf(line,"%d",&context->display_vertical_size);
-    if (width > 0 && height < 0) {
+    if (width > 0 && height > 0) {
       context->display_horizontal_size = width;
       context->display_vertical_size = height;
     }
@@ -593,17 +600,17 @@ readparmfile(simpeg_encode_context * context,
                                context->frame_pred_dct_tab,
                                context->frame_pred_dct_tab+1,
                                context->frame_pred_dct_tab+2);
-    
+
     fgets(line,254,fd); sscanf(line,"%d %d %d",
                                context->conceal_tab,
                                context->conceal_tab+1,
                                context->conceal_tab+2);
-    
+
     fgets(line,254,fd); sscanf(line,"%d %d %d",
                                context->qscale_tab,
                                context->qscale_tab+1,
                                context->qscale_tab+2);
-    
+
     fgets(line,254,fd); sscanf(line,"%d %d %d",
                                context->intravlc_tab,
                                context->intravlc_tab+1,
@@ -612,10 +619,10 @@ readparmfile(simpeg_encode_context * context,
                                context->altscan_tab,
                                context->altscan_tab+1,
                                context->altscan_tab+2);
-    
+
     fgets(line,254,fd); sscanf(line,"%d",&context->repeatfirst);
     fgets(line,254,fd); sscanf(line,"%d",&context->prog_frame);
-    /* intra slice interval refresh period */  
+    /* intra slice interval refresh period */
     fgets(line,254,fd); sscanf(line,"%d",&context->P);
     fgets(line,254,fd); sscanf(line,"%d",&context->r);
     fgets(line,254,fd); sscanf(line,"%lf",&context->avg_act);
@@ -625,7 +632,7 @@ readparmfile(simpeg_encode_context * context,
     fgets(line,254,fd); sscanf(line,"%d",&context->d0i);
     fgets(line,254,fd); sscanf(line,"%d",&context->d0p);
     fgets(line,254,fd); sscanf(line,"%d",&context->d0b);
-    
+
     if (context->N<1)
       simpeg_encode_error(context, "N must be positive");
     if (context->M<1)
@@ -633,28 +640,28 @@ readparmfile(simpeg_encode_context * context,
     if (context->N%context->M != 0)
       simpeg_encode_error(context,"N must be an integer multiple of M");
 
-    context->motion_data = (struct motion_data *)malloc(context->M*sizeof(struct motion_data));    
+    context->motion_data = (struct motion_data *)malloc(context->M*sizeof(struct motion_data));
     if (!context->motion_data)
       simpeg_encode_error(context, "malloc failed\n");
-    
+
     for (i=0; i<context->M; i++) {
       fgets(line,254,fd);
       sscanf(line,"%d %d %d %d",
-             &context->motion_data[i].forw_hor_f_code, 
+             &context->motion_data[i].forw_hor_f_code,
              &context->motion_data[i].forw_vert_f_code,
-             &context->motion_data[i].sxf, 
+             &context->motion_data[i].sxf,
              &context->motion_data[i].syf);
-      
+
       if (i!=0) {
         fgets(line,254,fd);
         sscanf(line,"%d %d %d %d",
-               &context->motion_data[i].back_hor_f_code, 
+               &context->motion_data[i].back_hor_f_code,
                &context->motion_data[i].back_vert_f_code,
-               &context->motion_data[i].sxb, 
+               &context->motion_data[i].sxb,
                &context->motion_data[i].syb);
       }
     }
-    
+
     fclose(fd);
   }
   else  if (mpeg1) { /* fill in some default values for mpeg1 */
@@ -668,7 +675,7 @@ readparmfile(simpeg_encode_context * context,
     context->nframes = 10;
     if (numframes > 0) context->nframes = numframes;
     context->frame0 = 0;
-    h = m = s = f = 0; 
+    h = m = s = f = 0;
 
     context->N = 6;
     context->M = 3;
@@ -687,6 +694,7 @@ readparmfile(simpeg_encode_context * context,
     context->aspectratio = 2;
     context->frame_rate_code = 3;
     context->bit_rate = 1152000.0;
+    if (bitrate > 0.0f) context->bit_rate = bitrate;
     context->vbv_buffer_size = 20;
     context->low_delay = 0;
     context->constrparms = 0;
@@ -702,7 +710,7 @@ readparmfile(simpeg_encode_context * context,
     context->display_horizontal_size = 704;
     context->display_vertical_size = 480;
 
-    if (width > 0 && height < 0) {
+    if (width > 0 && height > 0) {
       context->display_horizontal_size = width;
       context->display_vertical_size = height;
     }
@@ -712,15 +720,15 @@ readparmfile(simpeg_encode_context * context,
     context->frame_pred_dct_tab[0] = 1;
     context->frame_pred_dct_tab[1] = 1;
     context->frame_pred_dct_tab[2] = 1;
-    
+
     context->conceal_tab[0] = 0;
     context->conceal_tab[1] = 0;
     context->conceal_tab[2] = 0;
-    
+
     context->qscale_tab[0] = 0;
     context->qscale_tab[1] = 0;
     context->qscale_tab[2] = 0;
-    
+
     context->intravlc_tab[0] = 0;
     context->intravlc_tab[1] = 0;
     context->intravlc_tab[2] = 0;
@@ -728,7 +736,7 @@ readparmfile(simpeg_encode_context * context,
     context->altscan_tab[0] = 0;
     context->altscan_tab[1] = 0;
     context->altscan_tab[2] = 0;
-    
+
     context->repeatfirst = 0;
     context->prog_frame = 1;
 
@@ -741,7 +749,7 @@ readparmfile(simpeg_encode_context * context,
     context->d0i = 0;
     context->d0p = 0;
     context->d0b = 0;
-    
+
     if (context->N<1)
       simpeg_encode_error(context, "N must be positive");
     if (context->M<1)
@@ -749,10 +757,10 @@ readparmfile(simpeg_encode_context * context,
     if (context->N%context->M != 0)
       simpeg_encode_error(context,"N must be an integer multiple of M");
 
-    context->motion_data = (struct motion_data *)malloc(context->M*sizeof(struct motion_data));    
+    context->motion_data = (struct motion_data *)malloc(context->M*sizeof(struct motion_data));
     if (!context->motion_data)
       simpeg_encode_error(context, "malloc failed\n");
-        
+
     context->motion_data[0].forw_hor_f_code = 2;
     context->motion_data[0].forw_vert_f_code = 2;
     context->motion_data[0].sxf = 11;
@@ -762,20 +770,20 @@ readparmfile(simpeg_encode_context * context,
     context->motion_data[1].forw_vert_f_code = 1;
     context->motion_data[1].sxf = 3;
     context->motion_data[1].syf = 3;
-    
-    context->motion_data[1].back_hor_f_code = 1; 
+
+    context->motion_data[1].back_hor_f_code = 1;
     context->motion_data[1].back_vert_f_code = 1;
-    context->motion_data[1].sxb = 7; 
+    context->motion_data[1].sxb = 7;
     context->motion_data[1].syb = 7;
 
     context->motion_data[2].forw_hor_f_code = 1;
     context->motion_data[2].forw_vert_f_code = 1;
     context->motion_data[2].sxf = 7;
     context->motion_data[2].syf = 7;
-    
-    context->motion_data[2].back_hor_f_code = 1; 
+
+    context->motion_data[2].back_hor_f_code = 1;
     context->motion_data[2].back_vert_f_code = 1;
-    context->motion_data[2].sxb = 3; 
+    context->motion_data[2].sxb = 3;
     context->motion_data[2].syb = 3;
   }
   else { /* fill in some default values for mpeg2 */
@@ -789,7 +797,7 @@ readparmfile(simpeg_encode_context * context,
     context->nframes = 10;
     if (numframes > 0) context->nframes = numframes;
     context->frame0 = 0;
-    h = m = s = f = 0; 
+    h = m = s = f = 0;
 
     context->N = 6;
     context->M = 3;
@@ -808,6 +816,7 @@ readparmfile(simpeg_encode_context * context,
     context->aspectratio = 2;
     context->frame_rate_code = 5;
     context->bit_rate = 5000000.0;
+    if (bitrate > 0.0f) context->bit_rate = bitrate;
     context->vbv_buffer_size = 112;
     context->low_delay = 0;
     context->constrparms = 0;
@@ -823,7 +832,7 @@ readparmfile(simpeg_encode_context * context,
     context->display_horizontal_size = 704;
     context->display_vertical_size = 480;
 
-    if (width > 0 && height < 0) {
+    if (width > 0 && height > 0) {
       context->display_horizontal_size = width;
       context->display_vertical_size = height;
     }
@@ -833,15 +842,15 @@ readparmfile(simpeg_encode_context * context,
     context->frame_pred_dct_tab[0] = 0;
     context->frame_pred_dct_tab[1] = 0;
     context->frame_pred_dct_tab[2] = 0;
-    
+
     context->conceal_tab[0] = 0;
     context->conceal_tab[1] = 0;
     context->conceal_tab[2] = 0;
-    
+
     context->qscale_tab[0] = 1;
     context->qscale_tab[1] = 1;
     context->qscale_tab[2] = 1;
-    
+
     context->intravlc_tab[0] = 1;
     context->intravlc_tab[1] = 0;
     context->intravlc_tab[2] = 0;
@@ -849,7 +858,7 @@ readparmfile(simpeg_encode_context * context,
     context->altscan_tab[0] = 0;
     context->altscan_tab[1] = 0;
     context->altscan_tab[2] = 0;
-    
+
     context->repeatfirst = 0;
     context->prog_frame = 0;
 
@@ -862,7 +871,7 @@ readparmfile(simpeg_encode_context * context,
     context->d0i = 0;
     context->d0p = 0;
     context->d0b = 0;
-    
+
     if (context->N<1)
       simpeg_encode_error(context, "N must be positive");
     if (context->M<1)
@@ -870,10 +879,10 @@ readparmfile(simpeg_encode_context * context,
     if (context->N%context->M != 0)
       simpeg_encode_error(context,"N must be an integer multiple of M");
 
-    context->motion_data = (struct motion_data *)malloc(context->M*sizeof(struct motion_data));    
+    context->motion_data = (struct motion_data *)malloc(context->M*sizeof(struct motion_data));
     if (!context->motion_data)
       simpeg_encode_error(context, "malloc failed\n");
-        
+
     context->motion_data[0].forw_hor_f_code = 2;
     context->motion_data[0].forw_vert_f_code = 2;
     context->motion_data[0].sxf = 11;
@@ -883,20 +892,20 @@ readparmfile(simpeg_encode_context * context,
     context->motion_data[1].forw_vert_f_code = 1;
     context->motion_data[1].sxf = 3;
     context->motion_data[1].syf = 3;
-    
-    context->motion_data[1].back_hor_f_code = 1; 
+
+    context->motion_data[1].back_hor_f_code = 1;
     context->motion_data[1].back_vert_f_code = 1;
-    context->motion_data[1].sxb = 7; 
+    context->motion_data[1].sxb = 7;
     context->motion_data[1].syb = 7;
 
     context->motion_data[2].forw_hor_f_code = 1;
     context->motion_data[2].forw_vert_f_code = 1;
     context->motion_data[2].sxf = 7;
     context->motion_data[2].syf = 7;
-    
-    context->motion_data[2].back_hor_f_code = 1; 
+
+    context->motion_data[2].back_hor_f_code = 1;
     context->motion_data[2].back_vert_f_code = 1;
-    context->motion_data[2].sxb = 3; 
+    context->motion_data[2].sxb = 3;
     context->motion_data[2].syb = 3;
   }
 
@@ -920,7 +929,7 @@ readparmfile(simpeg_encode_context * context,
 
   /* make sure MPEG specific parameters are valid */
   simpeg_encode_range_checks(context);
-  
+
   context->frame_rate = ratetab[context->frame_rate_code-1];
 
   /* timecode -> frame number */
@@ -945,7 +954,7 @@ readparmfile(simpeg_encode_context * context,
         context->constrparms = 0;
       }
     }
-    
+
     if (context->constrparms) {
       for (i=0; i<context->M; i++) {
         if (context->motion_data[i].forw_hor_f_code > 4) {
@@ -954,7 +963,7 @@ readparmfile(simpeg_encode_context * context,
           context->constrparms = 0;
           break;
         }
-        
+
         if (context->motion_data[i].forw_vert_f_code > 4) {
           if (!context->quiet)
             SimpegWrite_warning(context,"setting constrained_parameters_flag = 0");
@@ -1008,7 +1017,7 @@ readparmfile(simpeg_encode_context * context,
           SimpegWrite_warning(context,"setting qscale_tab[%d] = 0", i);
         context->qscale_tab[i] = 0;
       }
-    
+
     for (i=0; i<3; i++)
       if (context->intravlc_tab[i]) {
         if (!context->quiet)
@@ -1023,7 +1032,7 @@ readparmfile(simpeg_encode_context * context,
         context->altscan_tab[i] = 0;
       }
   }
-  
+
   if (!context->mpeg1 && context->constrparms) {
     if (!context->quiet)
       SimpegWrite_warning(context,"setting constrained_parameters_flag = 0");
@@ -1119,17 +1128,17 @@ static void readquantmat(simpeg_encode_context * context)
       sprintf(context->errortext,"Couldn't open quant matrix file %s",context->iqname);
       simpeg_encode_error(context,context->errortext);
     }
-    
+
     for (i=0; i<64; i++) {
       fscanf(fd,"%d",&v);
       if (v<1 || v>255)
         simpeg_encode_error(context,"invalid value in quant matrix");
       context->intra_q[i] = v;
     }
-    
+
     fclose(fd);
   }
-  
+
   if (context->niqname[0]=='-') {
     /* use default non-intra matrix */
     context->load_niquant = 0;
@@ -1157,7 +1166,7 @@ static void readquantmat(simpeg_encode_context * context)
 
 static void init_context_data(simpeg_encode_context * context)
 {
-  static unsigned char zig_zag_scan[] = 
+  static unsigned char zig_zag_scan[] =
   {
     0,1,8,16,9,2,3,10,17,24,32,25,18,11,4,5,
     12,19,26,33,40,48,41,34,27,20,13,6,7,14,21,28,
@@ -1165,14 +1174,14 @@ static void init_context_data(simpeg_encode_context * context)
     58,59,52,45,38,31,39,46,53,60,61,54,47,55,62,63
   };
 
-  static unsigned char alternate_scan[] = 
+  static unsigned char alternate_scan[] =
   {
     0,8,16,24,1,9,2,10,17,25,32,40,48,56,57,49,
     41,33,26,18,3,11,4,12,19,27,34,42,50,58,35,43,
     51,59,20,28,5,13,6,14,21,29,36,44,52,60,37,45,
     53,61,22,30,7,15,23,31,38,46,54,62,39,47,55,63
   };
-  static unsigned char default_intra_quantizer_matrix[] = 
+  static unsigned char default_intra_quantizer_matrix[] =
   {
     8, 16, 19, 22, 26, 27, 29, 34,
     16, 16, 22, 24, 27, 29, 34, 37,
@@ -1183,14 +1192,14 @@ static void init_context_data(simpeg_encode_context * context)
     26, 27, 29, 34, 38, 46, 56, 69,
     27, 29, 35, 38, 46, 56, 69, 83
   };
-  static unsigned char non_linear_mquant_table[] = 
+  static unsigned char non_linear_mquant_table[] =
   {
     0, 1, 2, 3, 4, 5, 6, 7,
     8,10,12,14,16,18,20,22,
     24,28,32,36,40,44,48,52,
     56,64,72,80,88,96,104,112
   };
-  static unsigned char map_non_linear_mquant[] =  
+  static unsigned char map_non_linear_mquant[] =
   {
     0,1,2,3,4,5,6,7,8,8,9,9,10,10,11,11,12,12,13,13,14,14,15,15,16,16,
     16,17,17,17,18,18,18,18,19,19,19,19,20,20,20,20,21,21,21,21,22,22,
@@ -1198,23 +1207,23 @@ static void init_context_data(simpeg_encode_context * context)
     26,26,26,26,26,26,27,27,27,27,27,27,27,27,28,28,28,28,28,28,28,29,
       29,29,29,29,29,29,29,29,29,30,30,30,30,30,30,30,31,31,31,31,31
   };
-  
+
   /* initialize integers and pointers to 0 */
   memset(context, 0, sizeof(simpeg_encode_context));
-         
+
   strcpy(context->version, "mpeg2encode V1.2, 96/07/19");
   strcpy(context->author,"(C) 1996, MPEG Software Simulation Group");
-  
+
 
   memcpy(context->zig_zag_scan, zig_zag_scan, sizeof(zig_zag_scan));
-  
+
 
   memcpy(context->alternate_scan, alternate_scan, sizeof(alternate_scan));
-  
+
   memcpy(context->default_intra_quantizer_matrix,
-         default_intra_quantizer_matrix, 
+         default_intra_quantizer_matrix,
          sizeof(default_intra_quantizer_matrix));
-    
+
   memcpy(context->non_linear_mquant_table,
          non_linear_mquant_table,
          sizeof(non_linear_mquant_table));
