@@ -26,10 +26,18 @@ typedef struct _loader_data loader_data;
    Coin/src/nodes/SoTexture2.cpp. */
 
 /* built in image loaders */ 
+#ifdef SIMAGE_GDIPLUS_SUPPORT
+#include <simage_gdiplus.h>
+static loader_data gdiplus_loader;
+#endif /* SIMAGE_GDIPLUS_SUPPORT */
 #ifdef HAVE_JPEGLIB
 #include <simage_jpeg.h>
 static loader_data jpeg_loader;
 #endif /* HAVE_JPEGLIB */
+#ifdef HAVE_JASPER
+#include <simage_jasper.h>
+static loader_data jasper_loader;
+#endif /* HAVE_JASPER */
 #ifdef HAVE_PNGLIB
 #include <simage_png.h>
 static loader_data png_loader;
@@ -50,10 +58,10 @@ static loader_data pic_loader;
 #include <simage_rgb.h>
 static loader_data rgb_loader;
 #endif /* SIMAGE_PIC_SUPPORT */
-#ifdef HAVE_UNGIFLIB
+#ifdef HAVE_GIFLIB
 #include <simage_gif.h>
 static loader_data gif_loader;
-#endif /* HAVE_UNGIFLIB */
+#endif /* HAVE_GIFLIB */
 #ifdef SIMAGE_XWD_SUPPORT
 #include <simage_xwd.h>
 static loader_data xwd_loader;
@@ -66,6 +74,10 @@ static loader_data qimage_loader;
 #include <simage_quicktime.h>
 static loader_data quicktime_loader;
 #endif /* SIMAGE_QUICKTIME */
+#ifdef SIMAGE_CGIMAGE_SUPPORT
+#include <simage_cgimage.h>
+static loader_data cgimage_loader;
+#endif /* SIMAGE_CGIMAGE */
 
 #include <assert.h>
 
@@ -146,6 +158,16 @@ add_internal_loaders(void)
   static int first = 1;
   if (first) {
     first = 0;
+#ifdef SIMAGE_GDIPLUS_SUPPORT
+    add_loader(&gdiplus_loader,
+               simage_gdiplus_load,
+               simage_gdiplus_identify,
+               simage_gdiplus_error,
+               1, 0);
+    gdiplus_loader.openfuncs.open_func = simage_gdiplus_open;
+    gdiplus_loader.openfuncs.close_func = simage_gdiplus_close;
+    gdiplus_loader.openfuncs.read_line_func = simage_gdiplus_read_line;    
+#endif /* SIMAGE_GDIPLUS_SUPPORT */
 #ifdef HAVE_JPEGLIB
     add_loader(&jpeg_loader, 
 	       simage_jpeg_load,
@@ -177,6 +199,17 @@ add_internal_loaders(void)
     tiff_loader.openfuncs.close_func = simage_tiff_close;
     tiff_loader.openfuncs.read_line_func = simage_tiff_read_line;    
 #endif /* HAVE_TIFFLIB */
+#ifdef HAVE_JASPER
+    add_loader(&jasper_loader, 
+               simage_jasper_load,
+               simage_jasper_identify,
+               simage_jasper_error,
+               1, 0);
+    /* read_line API not supported by JASPER */
+    /* jasper_loader.openfuncs.open_func = simage_jasper_open;
+     * jasper_loader.openfuncs.close_func = simage_jasper_close;
+     * jasper_loader.openfuncs.read_line_func = simage_jasper_read_line;  */
+#endif /* HAVE_JASPER */
 #ifdef SIMAGE_RGB_SUPPORT
     add_loader(&rgb_loader, 
 	       simage_rgb_load,
@@ -194,13 +227,13 @@ add_internal_loaders(void)
 	       simage_pic_error,
 	       1, 0);
 #endif /* SIMAGE_PIC_SUPPORT */
-#ifdef HAVE_UNGIFLIB
+#ifdef HAVE_GIFLIB
     add_loader(&gif_loader, 
                simage_gif_load,
                simage_gif_identify,
                simage_gif_error,
                1, 0);
-#endif /* HAVE_UNGIFLIB */
+#endif /* HAVE_GIFLIB */
 #ifdef SIMAGE_XWD_SUPPORT
     add_loader(&xwd_loader,
                simage_xwd_load,
@@ -223,6 +256,14 @@ add_internal_loaders(void)
                1, 
                1); // add_before -- if we can use QuickTime, makeitso
 #endif /* SIMAGE_QUICKTIME_SUPPORT */
+#ifdef SIMAGE_CGIMAGE_SUPPORT
+    add_loader(&cgimage_loader,
+               simage_cgimage_load,
+               simage_cgimage_identify,
+               simage_cgimage_error,
+               1, 
+               1); // add_before -- if we can use CGImage, makeitso
+#endif /* SIMAGE_CGIMAGE_SUPPORT */
   }
 }
 
