@@ -1,5 +1,6 @@
 #include <simage_qimage.h>
 
+#include <qglobal.h>
 #include <qimage.h>
 #include <qstring.h>
 #include <stdio.h>
@@ -7,6 +8,17 @@
 #include <ctype.h>
 #include <stdlib.h>
 
+#if QT_VERSION > 0x040000
+#define QT4 1
+#else // QT version >= 4.0.0
+#define QT4 0
+#endif // QT version < 4.0.0
+
+#if QT4
+#include <qimagereader.h>
+#include <qimagewriter.h>
+#endif // QT4
+
 #define ERR_NO_ERROR          0
 #define ERR_OPEN              1
 #define ERR_MEM               2
@@ -40,7 +52,11 @@ simage_qimage_identify(const char * ptr,
                        const unsigned char *header,
                        int headerlen)
 {
+#if QT4
+  return ! QImageReader::imageFormat(QString(ptr)).isEmpty();
+#else
   return QImage::imageFormat(QString(ptr)) != NULL;
+#endif
 }
 
 unsigned char *
@@ -58,8 +74,14 @@ simage_qimage_load(const char * filename,
     if (image.depth() == 8 && image.isGrayscale()) 
       c = 1;
     else {
+#if QT4
+      c = image.hasAlphaChannel() ? 4 : 3;
+      image = image.convertToFormat(image.hasAlphaChannel() ? 
+                                    QImage::Format_ARGB32 : QImage::Format_RGB32);
+#else
       image = image.convertDepth(32);
       c = image.hasAlphaBuffer() ? 4 : 3;
+#endif
     }
 
     unsigned char *buffer = (unsigned char *)malloc(w*h*c);
@@ -116,6 +138,18 @@ qimage_set_save_format(const char * ext, char * buf)
   // Qt specifies the jpg extension as JPEG
   if (strcmp(buf, "JPG") == 0) strcpy(buf, "JPEG");
   
+#if QT4
+
+  QList <QByteArray> list = QImageWriter::supportedImageFormats();
+  const int n = list.size();
+  for (int i = 0; i < n; i++) {
+    if (strcmp(buf, list[i].constData()) == 0) return 1;
+  }
+  buf[0] = 0;
+  return 0;
+
+#else // QT4
+
   QStrList olist = QImage::outputFormats();
   const char * qtext = olist.getFirst();
   while (qtext) {
@@ -125,13 +159,34 @@ qimage_set_save_format(const char * ext, char * buf)
   // clear save format
   buf[0] = 0;
   return 0;
+
+#endif // !QT4
 }
 
 char * 
 simage_qimage_get_savers(void)
 {
-  QString str;
+#if QT4
 
+  QByteArray str;
+  QList <QByteArray> list = QImageWriter::supportedImageFormats();
+  const int n = list.size();
+  int first = 1;
+  for (int i = 0; i < n; i++) {
+    if (!first) str += ",";
+    first = 0;
+    str += list[i];
+  }
+  if (first) return NULL;
+  const char * asc = str.constData(); 
+  int len = strlen(asc);
+  char * dst = (char*) malloc(len+1);
+  strcpy(dst, asc);
+  return dst;
+
+#else // QT4
+
+  QString str;
   int first = 1;
   QStrList olist = QImage::outputFormats();
   const char * qtext = olist.getFirst();
@@ -142,12 +197,13 @@ simage_qimage_get_savers(void)
     qtext = olist.next();
   }
   if (first) return NULL; // no savers available
-  
   const char * asc = str.ascii();
   int len = strlen(asc);
   char * dst = (char*) malloc(len+1);
   strcpy(dst, asc);
   return dst;
+
+#endif // !QT4  
 }
 
 
@@ -166,9 +222,14 @@ simage_qimage_save(const char * filename,
     return 0;
   }
   
+#if QT4
+  QImage image(width, height, numcomponents == 2 || numcomponents == 4 ? 
+               QImage::Format_ARGB32 : QImage::Format_RGB32);
+#else // QT4
   QImage image(width, height, 32);
   if (numcomponents == 2 || numcomponents == 4) image.setAlphaBuffer(TRUE);
   else image.setAlphaBuffer(FALSE);
+#endif // !QT4
   QRgb * bits = (QRgb*) image.bits();
   
   for (int y = 0; y < height; y++) {
